R/Boot_parallel_survival.R
Boot_parallel_survival.RdParallel processing handling function for LimROTS survival
Boot_parallel_survival(
BPPARAM = NULL,
samples,
data,
formula.str,
meta.info,
a1,
a2,
pSamples,
competing_risks
)A parallel BPPARAM object for distributed computation.
bootstrapped samples matrix
A SummarizedExperiment object or a matrix where rows
represent features (e.g., genes, proteins) and columns represent samples.
The values should be log-transformed.
A formula string used when covariates are present in meta. info for modeling. It should include "~ 0 + ..." to exclude the intercept from the model.
A data frame containing sample-level metadata, where each
row corresponds to a sample. It should include the grouping variable
specified in group. If x is a SummarizedExperiment
object, meta.info must be a vector of the metadata needed for the
model to run and can be retrieved using colData().
Optional numeric value used in the optimization process. If defined by the user, no optimization occurs.
Optional numeric value used in the optimization process. If defined by the user, no optimization occurs.
a permutated list of samples
Logical. If TRUE, the competing
risks model via crr from cmprsk is used instead of the
standard Cox proportional hazards model.
A list containing: D, S, pD, pS for bootstrapped data and
for permuted data.