Check if SummarizedExperiment or data is correct

Check_SummarizedExperiment(
  x,
  assay.type = NULL,
  meta.info,
  group,
  survival = FALSE
)

Arguments

x

A matrix-like object or a SummarizedExperiment containing the data to be analyzed.

assay.type

A character string or numeric index specifying the assay to use if x is a SummarizedExperiment. Default is NULL

meta.info

Data frame. Metadata associated with the samples (columns of x). If x is a SummarizedExperiment,

group

Character. Column name in meta.info that defines the groups or conditions for comparison.

survival

Logical, indicating whether the analysis is survival analysis. Default is FALSE.

Value

a list of data , groups and meta.info